Imports System
Imports System.Data
Imports System.Data.SqlClient
Imports SearchSampleVB.BusinessObject

Namespace SearchSampleVB.DataLayer.Base
     ''' <summary>
     ''' Base class for CategoriesDataLayer.  Do not make changes to this class,
     ''' instead, put additional code in the CategoriesDataLayer class
     ''' </summary>
     Public Class CategoriesDataLayerBase

         ' constructor
         Public Sub New()
         End Sub

         ''' <summary>
         ''' Selects a record by primary key(s)
         ''' </summary>
         Public Shared Function SelectByPrimaryKey(ByVal categoryID As Integer) As Categories
              Dim storedProcName As String = "[dbo].[aspx_Categories_SelectByPrimaryKey]"
              Dim connection As SqlConnection = Dbase.GetConnection()
              Dim command As SqlCommand = Dbase.GetCommand(storedProcName, connection)

              ' parameters
              command.Parameters.AddWithValue("@categoryID", categoryID)

              Dim ds As DataSet = Dbase.GetDbaseDataSet(command)
              Dim objCategories As Categories = Nothing

              If ds.Tables(0).Rows.Count > 0 Then
                  objCategories = New Categories()
                  objCategories.CategoryID = DirectCast(ds.Tables(0).Rows(0)("CategoryID"), Integer)
                  objCategories.CategoryName = DirectCast(ds.Tables(0).Rows(0)("CategoryName"), String)

                  If Not ds.Tables(0).Rows(0)("Description").Equals(System.DBNull.Value) Then
                      objCategories.Description = DirectCast(ds.Tables(0).Rows(0)("Description"), String)
                  Else
                      objCategories.Description = Nothing
                  End If

              End If

            command.Dispose()
            connection.Close()
            connection.Dispose()
            ds.Dispose()

            Return objCategories
         End Function

         ''' <summary>
         ''' Gets the total number of records in the Categories table
         ''' </summary>
         Public Shared Function GetRecordCount() As Integer
             Return GetRecordCountShared("[dbo].[aspx_Categories_GetRecordCount]", Nothing, Nothing, True, Nothing)
         End Function

         Public Shared Function GetRecordCountShared(Optional ByVal storedProcName As String = Nothing, Optional ByVal param As String = Nothing, Optional ByVal paramValue As Object = Nothing, Optional ByVal isUseStoredProc As Boolean = True, Optional ByVal dynamicSQL As String = Nothing) As Integer
              Dim connection As SqlConnection = Dbase.GetConnection()
              Dim command As SqlCommand

              If isUseStoredProc Then
                  command = Dbase.GetCommand(storedProcName, connection)
              Else
                  command = new SqlCommand(dynamicSQL, connection)
              End If

              Dim ds As DataSet = Dbase.GetDbaseDataSet(command)
              Dim recordCount As Integer = 0

              If ds.Tables(0).Rows.Count > 0 Then
                  recordCount = DirectCast(ds.Tables(0).Rows(0)("RecordCount"), Integer)
              End If

              command.Dispose()
              connection.Close()
              connection.Dispose()
              ds.Dispose()

              Return recordCount
         End Function

         ''' <summary>
         ''' Gets the total number of records in the Categories table based on search parameters
         ''' </summary>
         Public Shared Function GetRecordCountDynamicWhere(categoryID As Integer?, categoryName As String) As Integer
              Dim storedProcName As String = "[dbo].[aspx_Categories_GetRecordCountWhereDynamic]"
              Dim connection As SqlConnection = Dbase.GetConnection()
              Dim command As SqlCommand = Dbase.GetCommand(storedProcName, connection)

              ' search parameters
              AddSearchCommandParamsShared(command, categoryID, categoryName)

              Dim ds As DataSet = Dbase.GetDbaseDataSet(command)
              Dim recordCount As Integer = 0

              If ds.Tables(0).Rows.Count > 0 Then
                  recordCount = DirectCast(ds.Tables(0).Rows(0)("RecordCount"), Integer)
              End If

              command.Dispose()
              connection.Close()
              connection.Dispose()
              ds.Dispose()

              Return recordCount
         End Function

         ''' <summary>
         ''' Selects Categories records sorted by the sortByExpression and returns records between the start and end
         ''' </summary>
         Public Shared Function SelectSkipAndTake(sortByExpression As String, start As Integer, ending As Integer) As CategoriesCollection
             Return SelectShared("[dbo].[aspx_Categories_SelectSkipAndTake]", Nothing, Nothing, True, Nothing, sortByExpression, start, ending)
         End Function

         Public Shared Function SelectSkipAndTakeDynamicWhere(categoryID As Integer?, categoryName As String, sortByExpression As String, start As Integer, ending  As Integer) As CategoriesCollection
              Dim storedProcName As String = "[dbo].[aspx_Categories_SelectSkipAndTakeWhereDynamic]"
              Dim connection As SqlConnection = Dbase.GetConnection()
              Dim command As SqlCommand = Dbase.GetCommand(storedProcName, connection)

              ' select, skip, take, sort parameters
              command.Parameters.AddWithValue("@start", start)
              command.Parameters.AddWithValue("@end", ending)
              command.Parameters.AddWithValue("@sortByExpression", sortByExpression)

              ' search parameters
              AddSearchCommandParamsShared(command, categoryID, categoryName)

              Dim ds As DataSet = Dbase.GetDbaseDataSet(command)
              Dim objCategoriesCol As CategoriesCollection = New CategoriesCollection()

              If ds.Tables(0).Rows.Count > 0 Then
                  For Each dr As DataRow in ds.Tables(0).Rows
                      Dim objCategories As Categories = CreateCategoriesFromDataRowShared(dr)
                      objCategoriesCol.Add(objCategories)
                  Next
              End If

              command.Dispose()
              connection.Close()
              connection.Dispose()
              ds.Dispose()

              Return objCategoriesCol
         End Function

         ''' <summary>
         ''' Selects all Categories
         ''' </summary>
         Public Shared Function SelectAll() As CategoriesCollection
             Return SelectShared("[dbo].[aspx_Categories_SelectAll]", String.Empty, Nothing)
         End Function

         ''' <summary>
         ''' Selects records based on the passed filters as a collection (List) of Categories.
         ''' </summary>
         Public Shared Function SelectAllDynamicWhere(categoryID As System.Nullable(Of Integer), categoryName As String) As CategoriesCollection
              Dim storedProcName As String = "[dbo].[aspx_Categories_SelectAllWhereDynamic]"
              Dim connection As SqlConnection = Dbase.GetConnection()
              Dim command As SqlCommand = Dbase.GetCommand(storedProcName, connection)

              ' parameters
              command.Parameters.AddWithValue("@categoryID", categoryID)
              command.Parameters.AddWithValue("@categoryName", categoryName)


              Dim ds As DataSet = Dbase.GetDbaseDataSet(command)
              Dim objCategoriesCol As New CategoriesCollection()
              Dim objCategories As Categories

              If ds.Tables(0).Rows.Count > 0 Then
                 For Each dr As DataRow In ds.Tables(0).Rows
                     objCategories = New Categories()
                     objCategories.CategoryID = DirectCast(dr("CategoryID"), Integer)
                     objCategories.CategoryName = dr("CategoryName").ToString()

                     If Not System.DbNull.Value.Equals(dr("Description")) Then
                         objCategories.Description = dr("Description").ToString()
                     Else
                         objCategories.Description = Nothing
                     End If

                     objCategoriesCol.Add(objCategories)
                 Next
              End If

              command.Dispose()
              connection.Close()
              connection.Dispose()
              ds.Dispose()

              Return objCategoriesCol
         End Function

         ''' <summary>
         ''' Selects CategoryID and CategoryName columns for use with a DropDownList web control
         ''' </summary>
         Public Shared Function SelectCategoriesDropDownListData() As CategoriesCollection
              Dim storedProcName As String = "[dbo].[aspx_Categories_SelectDropDownListData]"
              Dim connection As SqlConnection = Dbase.GetConnection()
              Dim command As SqlCommand = Dbase.GetCommand(storedProcName, connection)

              Dim ds As DataSet = Dbase.GetDbaseDataSet(command)
              Dim objCategoriesCol As New CategoriesCollection()
              Dim objCategories As Categories

              If ds.Tables(0).Rows.Count > 0 Then
                 For Each dr As DataRow In ds.Tables(0).Rows
                     objCategories = New Categories()
                     objCategories.CategoryID = DirectCast(dr("CategoryID"), Integer)
                     objCategories.CategoryName = DirectCast(dr("CategoryName"), String)

                     objCategoriesCol.Add(objCategories)
                 Next
              End If

              command.Dispose()
              connection.Close()
              connection.Dispose()
              ds.Dispose()

              Return objCategoriesCol
         End Function

         Public Shared Function SelectShared(storedProcName As String, param As String, paramValue As Object, Optional ByVal isUseStoredProc As Boolean = True, Optional ByVal dynamicSQL As String = Nothing, Optional ByVal sortByExpression As String = Nothing, Optional ByVal start As Integer? = Nothing, Optional ByVal ending As Integer? = Nothing) As CategoriesCollection
              Dim connection As SqlConnection = Dbase.GetConnection()
              Dim command As SqlCommand

              If isUseStoredProc Then
                  command = Dbase.GetCommand(storedProcName, connection)
              Else
                  command = new SqlCommand(dynamicSQL, connection)
              End If

              ' select, skip, take, sort parameters
              If Not [String].IsNullOrEmpty(sortByExpression) AndAlso start IsNot Nothing AndAlso ending IsNot Nothing Then
                  command.Parameters.AddWithValue("@start", start.Value)
                  command.Parameters.AddWithValue("@end", ending.Value)
                  command.Parameters.AddWithValue("@sortByExpression", sortByExpression)
              End If

              Dim ds As DataSet = Dbase.GetDbaseDataSet(command)
              Dim objCategoriesCol As New CategoriesCollection()

              If ds.Tables(0).Rows.Count > 0 Then
                 For Each dr As DataRow In ds.Tables(0).Rows
                     Dim objCategories As Categories = CreateCategoriesFromDataRowShared(dr)
                     objCategoriesCol.Add(objCategories)
                 Next
              End If

              command.Dispose()
              connection.Close()
              connection.Dispose()
              ds.Dispose()

              Return objCategoriesCol
         End Function

         ''' <summary>
         ''' Inserts a record
         ''' </summary>
         Public Shared Function Insert(objCategories As Categories) As Integer
             Dim storedProcName As String = "[dbo].[aspx_Categories_Insert]"
             Return InsertUpdate(objCategories, False, storedProcName)
         End Function

         ''' <summary>
         ''' Updates a record
         ''' </summary>
         Public Shared Sub Update(objCategories As Categories)
             Dim storedProcName As String = "[dbo].[aspx_Categories_Update]"
             InsertUpdate(objCategories, True, storedProcName)
         End Sub

         Private Shared Function InsertUpdate(ByVal objCategories As Categories, isUpdate As Boolean, storedProcName As String) As Integer
             Dim connection As SqlConnection = Dbase.GetConnection()
             Dim command As SqlCommand = Dbase.GetCommand(storedProcName, connection)

             Dim description As Object = objCategories.Description

             If String.IsNullOrEmpty(objCategories.Description) Then
                 description = System.DBNull.Value
             End If

             ' for update only
             If isUpdate Then
                 command.Parameters.AddWithValue("@categoryID", objCategories.CategoryID)
             End If

             command.Parameters.AddWithValue("@categoryName", objCategories.CategoryName)
             command.Parameters.AddWithValue("@description", description)

             ' execute and return value
             Dim newlyCreatedCategoryID As Integer = objCategories.CategoryID

             If isUpdate Then
                 command.ExecuteNonQuery()
             Else
                 newlyCreatedCategoryID = DirectCast(command.ExecuteScalar(), Integer)
             End If

             command.Dispose()
             connection.Close()
             connection.Dispose()

             Return newlyCreatedCategoryID
         End Function

         ''' <summary>
         ''' Deletes a record based on primary key(s)
         ''' </summary>
         Public Shared Sub Delete(ByVal categoryID As Integer)
             Dim connection As SqlConnection = Dbase.GetConnection()
             Dim command As SqlCommand = Dbase.GetCommand("[dbo].[aspx_Categories_Delete]", connection)

             command.Parameters.AddWithValue("@categoryID", categoryID)

             ' execute stored proc
             command.ExecuteNonQuery()
             command.Dispose()
             connection.Close()
             connection.Dispose()
         End Sub

         ''' <summary>
         ''' Adds search parameters to the Command object
         ''' </summary>
         Private Shared Sub AddSearchCommandParamsShared(command As SqlCommand, categoryID As Integer?, categoryName As String)
              If Not categoryID Is Nothing Then
                  command.Parameters.AddWithValue("@categoryID", categoryID)
              Else
                  command.Parameters.AddWithValue("@categoryID", System.DBNull.Value)
              End If

              If Not [String].IsNullOrEmpty(categoryName) Then
                  command.Parameters.AddWithValue("@categoryName", categoryName)
              Else
                  command.Parameters.AddWithValue("@categoryName", System.DBNull.Value)
              End If

         End Sub

         ''' <summary>
         ''' Creates a Categories object from the passed data row
         ''' </summary>
         Private Shared Function CreateCategoriesFromDataRowShared(dr As DataRow) As Categories
             Dim objCategories As Categories = New Categories()

             objCategories.CategoryID = DirectCast(dr("CategoryID"), Integer)
             objCategories.CategoryName = dr("CategoryName").ToString()

             If Not DbNull.Value.Equals(dr("Description")) Then
                 objCategories.Description = dr("Description").ToString()
             Else
                 objCategories.Description = Nothing
             End If

             Return objCategories
         End Function
     End Class
End Namespace
