Imports System
Imports System.Data
Imports System.Data.SqlClient
Imports SearchSampleVB.BusinessObject

Namespace SearchSampleVB.DataLayer.Base
     ''' <summary>
     ''' Base class for SuppliersDataLayer.  Do not make changes to this class,
     ''' instead, put additional code in the SuppliersDataLayer class
     ''' </summary>
     Public Class SuppliersDataLayerBase

         ' constructor
         Public Sub New()
         End Sub

         ''' <summary>
         ''' Selects a record by primary key(s)
         ''' </summary>
         Public Shared Function SelectByPrimaryKey(ByVal supplierID As Integer) As Suppliers
              Dim storedProcName As String = "[dbo].[aspx_Suppliers_SelectByPrimaryKey]"
              Dim connection As SqlConnection = Dbase.GetConnection()
              Dim command As SqlCommand = Dbase.GetCommand(storedProcName, connection)

              ' parameters
              command.Parameters.AddWithValue("@supplierID", supplierID)

              Dim ds As DataSet = Dbase.GetDbaseDataSet(command)
              Dim objSuppliers As Suppliers = Nothing

              If ds.Tables(0).Rows.Count > 0 Then
                  objSuppliers = New Suppliers()
                  objSuppliers.SupplierID = DirectCast(ds.Tables(0).Rows(0)("SupplierID"), Integer)
                  objSuppliers.CompanyName = DirectCast(ds.Tables(0).Rows(0)("CompanyName"), String)

                  If Not ds.Tables(0).Rows(0)("ContactName").Equals(System.DBNull.Value) Then
                      objSuppliers.ContactName = DirectCast(ds.Tables(0).Rows(0)("ContactName"), String)
                  Else
                      objSuppliers.ContactName = Nothing
                  End If

                  If Not ds.Tables(0).Rows(0)("ContactTitle").Equals(System.DBNull.Value) Then
                      objSuppliers.ContactTitle = DirectCast(ds.Tables(0).Rows(0)("ContactTitle"), String)
                  Else
                      objSuppliers.ContactTitle = Nothing
                  End If

                  If Not ds.Tables(0).Rows(0)("Address").Equals(System.DBNull.Value) Then
                      objSuppliers.Address = DirectCast(ds.Tables(0).Rows(0)("Address"), String)
                  Else
                      objSuppliers.Address = Nothing
                  End If

                  If Not ds.Tables(0).Rows(0)("City").Equals(System.DBNull.Value) Then
                      objSuppliers.City = DirectCast(ds.Tables(0).Rows(0)("City"), String)
                  Else
                      objSuppliers.City = Nothing
                  End If

                  If Not ds.Tables(0).Rows(0)("Region").Equals(System.DBNull.Value) Then
                      objSuppliers.Region = DirectCast(ds.Tables(0).Rows(0)("Region"), String)
                  Else
                      objSuppliers.Region = Nothing
                  End If

                  If Not ds.Tables(0).Rows(0)("PostalCode").Equals(System.DBNull.Value) Then
                      objSuppliers.PostalCode = DirectCast(ds.Tables(0).Rows(0)("PostalCode"), String)
                  Else
                      objSuppliers.PostalCode = Nothing
                  End If

                  If Not ds.Tables(0).Rows(0)("Country").Equals(System.DBNull.Value) Then
                      objSuppliers.Country = DirectCast(ds.Tables(0).Rows(0)("Country"), String)
                  Else
                      objSuppliers.Country = Nothing
                  End If

                  If Not ds.Tables(0).Rows(0)("Phone").Equals(System.DBNull.Value) Then
                      objSuppliers.Phone = DirectCast(ds.Tables(0).Rows(0)("Phone"), String)
                  Else
                      objSuppliers.Phone = Nothing
                  End If

                  If Not ds.Tables(0).Rows(0)("Fax").Equals(System.DBNull.Value) Then
                      objSuppliers.Fax = DirectCast(ds.Tables(0).Rows(0)("Fax"), String)
                  Else
                      objSuppliers.Fax = Nothing
                  End If

                  If Not ds.Tables(0).Rows(0)("HomePage").Equals(System.DBNull.Value) Then
                      objSuppliers.HomePage = DirectCast(ds.Tables(0).Rows(0)("HomePage"), String)
                  Else
                      objSuppliers.HomePage = Nothing
                  End If

              End If

            command.Dispose()
            connection.Close()
            connection.Dispose()
            ds.Dispose()

            Return objSuppliers
         End Function

         ''' <summary>
         ''' Gets the total number of records in the Suppliers table
         ''' </summary>
         Public Shared Function GetRecordCount() As Integer
             Return GetRecordCountShared("[dbo].[aspx_Suppliers_GetRecordCount]", Nothing, Nothing, True, Nothing)
         End Function

         Public Shared Function GetRecordCountShared(Optional ByVal storedProcName As String = Nothing, Optional ByVal param As String = Nothing, Optional ByVal paramValue As Object = Nothing, Optional ByVal isUseStoredProc As Boolean = True, Optional ByVal dynamicSQL As String = Nothing) As Integer
              Dim connection As SqlConnection = Dbase.GetConnection()
              Dim command As SqlCommand

              If isUseStoredProc Then
                  command = Dbase.GetCommand(storedProcName, connection)
              Else
                  command = new SqlCommand(dynamicSQL, connection)
              End If

              Dim ds As DataSet = Dbase.GetDbaseDataSet(command)
              Dim recordCount As Integer = 0

              If ds.Tables(0).Rows.Count > 0 Then
                  recordCount = DirectCast(ds.Tables(0).Rows(0)("RecordCount"), Integer)
              End If

              command.Dispose()
              connection.Close()
              connection.Dispose()
              ds.Dispose()

              Return recordCount
         End Function

         ''' <summary>
         ''' Gets the total number of records in the Suppliers table based on search parameters
         ''' </summary>
         Public Shared Function GetRecordCountDynamicWhere(supplierID As Integer?, companyName As String, contactName As String, contactTitle As String, address As String, city As String, region As String, postalCode As String, country As String, phone As String, fax As String) As Integer
              Dim storedProcName As String = "[dbo].[aspx_Suppliers_GetRecordCountWhereDynamic]"
              Dim connection As SqlConnection = Dbase.GetConnection()
              Dim command As SqlCommand = Dbase.GetCommand(storedProcName, connection)

              ' search parameters
              AddSearchCommandParamsShared(command, supplierID, companyName, contactName, contactTitle, address, city, region, postalCode, country, phone, fax)

              Dim ds As DataSet = Dbase.GetDbaseDataSet(command)
              Dim recordCount As Integer = 0

              If ds.Tables(0).Rows.Count > 0 Then
                  recordCount = DirectCast(ds.Tables(0).Rows(0)("RecordCount"), Integer)
              End If

              command.Dispose()
              connection.Close()
              connection.Dispose()
              ds.Dispose()

              Return recordCount
         End Function

         ''' <summary>
         ''' Selects Suppliers records sorted by the sortByExpression and returns records between the start and end
         ''' </summary>
         Public Shared Function SelectSkipAndTake(sortByExpression As String, start As Integer, ending As Integer) As SuppliersCollection
             Return SelectShared("[dbo].[aspx_Suppliers_SelectSkipAndTake]", Nothing, Nothing, True, Nothing, sortByExpression, start, ending)
         End Function

         Public Shared Function SelectSkipAndTakeDynamicWhere(supplierID As Integer?, companyName As String, contactName As String, contactTitle As String, address As String, city As String, region As String, postalCode As String, country As String, phone As String, fax As String, sortByExpression As String, start As Integer, ending  As Integer) As SuppliersCollection
              Dim storedProcName As String = "[dbo].[aspx_Suppliers_SelectSkipAndTakeWhereDynamic]"
              Dim connection As SqlConnection = Dbase.GetConnection()
              Dim command As SqlCommand = Dbase.GetCommand(storedProcName, connection)

              ' select, skip, take, sort parameters
              command.Parameters.AddWithValue("@start", start)
              command.Parameters.AddWithValue("@end", ending)
              command.Parameters.AddWithValue("@sortByExpression", sortByExpression)

              ' search parameters
              AddSearchCommandParamsShared(command, supplierID, companyName, contactName, contactTitle, address, city, region, postalCode, country, phone, fax)

              Dim ds As DataSet = Dbase.GetDbaseDataSet(command)
              Dim objSuppliersCol As SuppliersCollection = New SuppliersCollection()

              If ds.Tables(0).Rows.Count > 0 Then
                  For Each dr As DataRow in ds.Tables(0).Rows
                      Dim objSuppliers As Suppliers = CreateSuppliersFromDataRowShared(dr)
                      objSuppliersCol.Add(objSuppliers)
                  Next
              End If

              command.Dispose()
              connection.Close()
              connection.Dispose()
              ds.Dispose()

              Return objSuppliersCol
         End Function

         ''' <summary>
         ''' Selects all Suppliers
         ''' </summary>
         Public Shared Function SelectAll() As SuppliersCollection
             Return SelectShared("[dbo].[aspx_Suppliers_SelectAll]", String.Empty, Nothing)
         End Function

         ''' <summary>
         ''' Selects records based on the passed filters as a collection (List) of Suppliers.
         ''' </summary>
         Public Shared Function SelectAllDynamicWhere(supplierID As System.Nullable(Of Integer), companyName As String, contactName As String, contactTitle As String, address As String, city As String, region As String, postalCode As String, country As String, phone As String, fax As String) As SuppliersCollection
              Dim storedProcName As String = "[dbo].[aspx_Suppliers_SelectAllWhereDynamic]"
              Dim connection As SqlConnection = Dbase.GetConnection()
              Dim command As SqlCommand = Dbase.GetCommand(storedProcName, connection)

              ' parameters
              command.Parameters.AddWithValue("@supplierID", supplierID)
              command.Parameters.AddWithValue("@companyName", companyName)
              command.Parameters.AddWithValue("@contactName", contactName)
              command.Parameters.AddWithValue("@contactTitle", contactTitle)
              command.Parameters.AddWithValue("@address", address)
              command.Parameters.AddWithValue("@city", city)
              command.Parameters.AddWithValue("@region", region)
              command.Parameters.AddWithValue("@postalCode", postalCode)
              command.Parameters.AddWithValue("@country", country)
              command.Parameters.AddWithValue("@phone", phone)
              command.Parameters.AddWithValue("@fax", fax)


              Dim ds As DataSet = Dbase.GetDbaseDataSet(command)
              Dim objSuppliersCol As New SuppliersCollection()
              Dim objSuppliers As Suppliers

              If ds.Tables(0).Rows.Count > 0 Then
                 For Each dr As DataRow In ds.Tables(0).Rows
                     objSuppliers = New Suppliers()
                     objSuppliers.SupplierID = DirectCast(dr("SupplierID"), Integer)
                     objSuppliers.CompanyName = dr("CompanyName").ToString()

                     If Not System.DbNull.Value.Equals(dr("ContactName")) Then
                         objSuppliers.ContactName = dr("ContactName").ToString()
                     Else
                         objSuppliers.ContactName = Nothing
                     End If

                     If Not System.DbNull.Value.Equals(dr("ContactTitle")) Then
                         objSuppliers.ContactTitle = dr("ContactTitle").ToString()
                     Else
                         objSuppliers.ContactTitle = Nothing
                     End If

                     If Not System.DbNull.Value.Equals(dr("Address")) Then
                         objSuppliers.Address = dr("Address").ToString()
                     Else
                         objSuppliers.Address = Nothing
                     End If

                     If Not System.DbNull.Value.Equals(dr("City")) Then
                         objSuppliers.City = dr("City").ToString()
                     Else
                         objSuppliers.City = Nothing
                     End If

                     If Not System.DbNull.Value.Equals(dr("Region")) Then
                         objSuppliers.Region = dr("Region").ToString()
                     Else
                         objSuppliers.Region = Nothing
                     End If

                     If Not System.DbNull.Value.Equals(dr("PostalCode")) Then
                         objSuppliers.PostalCode = dr("PostalCode").ToString()
                     Else
                         objSuppliers.PostalCode = Nothing
                     End If

                     If Not System.DbNull.Value.Equals(dr("Country")) Then
                         objSuppliers.Country = dr("Country").ToString()
                     Else
                         objSuppliers.Country = Nothing
                     End If

                     If Not System.DbNull.Value.Equals(dr("Phone")) Then
                         objSuppliers.Phone = dr("Phone").ToString()
                     Else
                         objSuppliers.Phone = Nothing
                     End If

                     If Not System.DbNull.Value.Equals(dr("Fax")) Then
                         objSuppliers.Fax = dr("Fax").ToString()
                     Else
                         objSuppliers.Fax = Nothing
                     End If

                     If Not System.DbNull.Value.Equals(dr("HomePage")) Then
                         objSuppliers.HomePage = dr("HomePage").ToString()
                     Else
                         objSuppliers.HomePage = Nothing
                     End If

                     objSuppliersCol.Add(objSuppliers)
                 Next
              End If

              command.Dispose()
              connection.Close()
              connection.Dispose()
              ds.Dispose()

              Return objSuppliersCol
         End Function

         ''' <summary>
         ''' Selects SupplierID and CompanyName columns for use with a DropDownList web control
         ''' </summary>
         Public Shared Function SelectSuppliersDropDownListData() As SuppliersCollection
              Dim storedProcName As String = "[dbo].[aspx_Suppliers_SelectDropDownListData]"
              Dim connection As SqlConnection = Dbase.GetConnection()
              Dim command As SqlCommand = Dbase.GetCommand(storedProcName, connection)

              Dim ds As DataSet = Dbase.GetDbaseDataSet(command)
              Dim objSuppliersCol As New SuppliersCollection()
              Dim objSuppliers As Suppliers

              If ds.Tables(0).Rows.Count > 0 Then
                 For Each dr As DataRow In ds.Tables(0).Rows
                     objSuppliers = New Suppliers()
                     objSuppliers.SupplierID = DirectCast(dr("SupplierID"), Integer)
                     objSuppliers.CompanyName = DirectCast(dr("CompanyName"), String)

                     objSuppliersCol.Add(objSuppliers)
                 Next
              End If

              command.Dispose()
              connection.Close()
              connection.Dispose()
              ds.Dispose()

              Return objSuppliersCol
         End Function

         Public Shared Function SelectShared(storedProcName As String, param As String, paramValue As Object, Optional ByVal isUseStoredProc As Boolean = True, Optional ByVal dynamicSQL As String = Nothing, Optional ByVal sortByExpression As String = Nothing, Optional ByVal start As Integer? = Nothing, Optional ByVal ending As Integer? = Nothing) As SuppliersCollection
              Dim connection As SqlConnection = Dbase.GetConnection()
              Dim command As SqlCommand

              If isUseStoredProc Then
                  command = Dbase.GetCommand(storedProcName, connection)
              Else
                  command = new SqlCommand(dynamicSQL, connection)
              End If

              ' select, skip, take, sort parameters
              If Not [String].IsNullOrEmpty(sortByExpression) AndAlso start IsNot Nothing AndAlso ending IsNot Nothing Then
                  command.Parameters.AddWithValue("@start", start.Value)
                  command.Parameters.AddWithValue("@end", ending.Value)
                  command.Parameters.AddWithValue("@sortByExpression", sortByExpression)
              End If

              Dim ds As DataSet = Dbase.GetDbaseDataSet(command)
              Dim objSuppliersCol As New SuppliersCollection()

              If ds.Tables(0).Rows.Count > 0 Then
                 For Each dr As DataRow In ds.Tables(0).Rows
                     Dim objSuppliers As Suppliers = CreateSuppliersFromDataRowShared(dr)
                     objSuppliersCol.Add(objSuppliers)
                 Next
              End If

              command.Dispose()
              connection.Close()
              connection.Dispose()
              ds.Dispose()

              Return objSuppliersCol
         End Function

         ''' <summary>
         ''' Inserts a record
         ''' </summary>
         Public Shared Function Insert(objSuppliers As Suppliers) As Integer
             Dim storedProcName As String = "[dbo].[aspx_Suppliers_Insert]"
             Return InsertUpdate(objSuppliers, False, storedProcName)
         End Function

         ''' <summary>
         ''' Updates a record
         ''' </summary>
         Public Shared Sub Update(objSuppliers As Suppliers)
             Dim storedProcName As String = "[dbo].[aspx_Suppliers_Update]"
             InsertUpdate(objSuppliers, True, storedProcName)
         End Sub

         Private Shared Function InsertUpdate(ByVal objSuppliers As Suppliers, isUpdate As Boolean, storedProcName As String) As Integer
             Dim connection As SqlConnection = Dbase.GetConnection()
             Dim command As SqlCommand = Dbase.GetCommand(storedProcName, connection)

             Dim contactName As Object = objSuppliers.ContactName
             Dim contactTitle As Object = objSuppliers.ContactTitle
             Dim address As Object = objSuppliers.Address
             Dim city As Object = objSuppliers.City
             Dim region As Object = objSuppliers.Region
             Dim postalCode As Object = objSuppliers.PostalCode
             Dim country As Object = objSuppliers.Country
             Dim phone As Object = objSuppliers.Phone
             Dim fax As Object = objSuppliers.Fax
             Dim homePage As Object = objSuppliers.HomePage

             If String.IsNullOrEmpty(objSuppliers.ContactName) Then
                 contactName = System.DBNull.Value
             End If

             If String.IsNullOrEmpty(objSuppliers.ContactTitle) Then
                 contactTitle = System.DBNull.Value
             End If

             If String.IsNullOrEmpty(objSuppliers.Address) Then
                 address = System.DBNull.Value
             End If

             If String.IsNullOrEmpty(objSuppliers.City) Then
                 city = System.DBNull.Value
             End If

             If String.IsNullOrEmpty(objSuppliers.Region) Then
                 region = System.DBNull.Value
             End If

             If String.IsNullOrEmpty(objSuppliers.PostalCode) Then
                 postalCode = System.DBNull.Value
             End If

             If String.IsNullOrEmpty(objSuppliers.Country) Then
                 country = System.DBNull.Value
             End If

             If String.IsNullOrEmpty(objSuppliers.Phone) Then
                 phone = System.DBNull.Value
             End If

             If String.IsNullOrEmpty(objSuppliers.Fax) Then
                 fax = System.DBNull.Value
             End If

             If String.IsNullOrEmpty(objSuppliers.HomePage) Then
                 homePage = System.DBNull.Value
             End If

             ' for update only
             If isUpdate Then
                 command.Parameters.AddWithValue("@supplierID", objSuppliers.SupplierID)
             End If

             command.Parameters.AddWithValue("@companyName", objSuppliers.CompanyName)
             command.Parameters.AddWithValue("@contactName", contactName)
             command.Parameters.AddWithValue("@contactTitle", contactTitle)
             command.Parameters.AddWithValue("@address", address)
             command.Parameters.AddWithValue("@city", city)
             command.Parameters.AddWithValue("@region", region)
             command.Parameters.AddWithValue("@postalCode", postalCode)
             command.Parameters.AddWithValue("@country", country)
             command.Parameters.AddWithValue("@phone", phone)
             command.Parameters.AddWithValue("@fax", fax)
             command.Parameters.AddWithValue("@homePage", homePage)

             ' execute and return value
             Dim newlyCreatedSupplierID As Integer = objSuppliers.SupplierID

             If isUpdate Then
                 command.ExecuteNonQuery()
             Else
                 newlyCreatedSupplierID = DirectCast(command.ExecuteScalar(), Integer)
             End If

             command.Dispose()
             connection.Close()
             connection.Dispose()

             Return newlyCreatedSupplierID
         End Function

         ''' <summary>
         ''' Deletes a record based on primary key(s)
         ''' </summary>
         Public Shared Sub Delete(ByVal supplierID As Integer)
             Dim connection As SqlConnection = Dbase.GetConnection()
             Dim command As SqlCommand = Dbase.GetCommand("[dbo].[aspx_Suppliers_Delete]", connection)

             command.Parameters.AddWithValue("@supplierID", supplierID)

             ' execute stored proc
             command.ExecuteNonQuery()
             command.Dispose()
             connection.Close()
             connection.Dispose()
         End Sub

         ''' <summary>
         ''' Adds search parameters to the Command object
         ''' </summary>
         Private Shared Sub AddSearchCommandParamsShared(command As SqlCommand, supplierID As Integer?, companyName As String, contactName As String, contactTitle As String, address As String, city As String, region As String, postalCode As String, country As String, phone As String, fax As String)
              If Not supplierID Is Nothing Then
                  command.Parameters.AddWithValue("@supplierID", supplierID)
              Else
                  command.Parameters.AddWithValue("@supplierID", System.DBNull.Value)
              End If

              If Not [String].IsNullOrEmpty(companyName) Then
                  command.Parameters.AddWithValue("@companyName", companyName)
              Else
                  command.Parameters.AddWithValue("@companyName", System.DBNull.Value)
              End If

              If Not [String].IsNullOrEmpty(contactName) Then
                  command.Parameters.AddWithValue("@contactName", contactName)
              Else
                  command.Parameters.AddWithValue("@contactName", System.DBNull.Value)
              End If

              If Not [String].IsNullOrEmpty(contactTitle) Then
                  command.Parameters.AddWithValue("@contactTitle", contactTitle)
              Else
                  command.Parameters.AddWithValue("@contactTitle", System.DBNull.Value)
              End If

              If Not [String].IsNullOrEmpty(address) Then
                  command.Parameters.AddWithValue("@address", address)
              Else
                  command.Parameters.AddWithValue("@address", System.DBNull.Value)
              End If

              If Not [String].IsNullOrEmpty(city) Then
                  command.Parameters.AddWithValue("@city", city)
              Else
                  command.Parameters.AddWithValue("@city", System.DBNull.Value)
              End If

              If Not [String].IsNullOrEmpty(region) Then
                  command.Parameters.AddWithValue("@region", region)
              Else
                  command.Parameters.AddWithValue("@region", System.DBNull.Value)
              End If

              If Not [String].IsNullOrEmpty(postalCode) Then
                  command.Parameters.AddWithValue("@postalCode", postalCode)
              Else
                  command.Parameters.AddWithValue("@postalCode", System.DBNull.Value)
              End If

              If Not [String].IsNullOrEmpty(country) Then
                  command.Parameters.AddWithValue("@country", country)
              Else
                  command.Parameters.AddWithValue("@country", System.DBNull.Value)
              End If

              If Not [String].IsNullOrEmpty(phone) Then
                  command.Parameters.AddWithValue("@phone", phone)
              Else
                  command.Parameters.AddWithValue("@phone", System.DBNull.Value)
              End If

              If Not [String].IsNullOrEmpty(fax) Then
                  command.Parameters.AddWithValue("@fax", fax)
              Else
                  command.Parameters.AddWithValue("@fax", System.DBNull.Value)
              End If

         End Sub

         ''' <summary>
         ''' Creates a Suppliers object from the passed data row
         ''' </summary>
         Private Shared Function CreateSuppliersFromDataRowShared(dr As DataRow) As Suppliers
             Dim objSuppliers As Suppliers = New Suppliers()

             objSuppliers.SupplierID = DirectCast(dr("SupplierID"), Integer)
             objSuppliers.CompanyName = dr("CompanyName").ToString()

             If Not DbNull.Value.Equals(dr("ContactName")) Then
                 objSuppliers.ContactName = dr("ContactName").ToString()
             Else
                 objSuppliers.ContactName = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ContactTitle")) Then
                 objSuppliers.ContactTitle = dr("ContactTitle").ToString()
             Else
                 objSuppliers.ContactTitle = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Address")) Then
                 objSuppliers.Address = dr("Address").ToString()
             Else
                 objSuppliers.Address = Nothing
             End If

             If Not DbNull.Value.Equals(dr("City")) Then
                 objSuppliers.City = dr("City").ToString()
             Else
                 objSuppliers.City = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Region")) Then
                 objSuppliers.Region = dr("Region").ToString()
             Else
                 objSuppliers.Region = Nothing
             End If

             If Not DbNull.Value.Equals(dr("PostalCode")) Then
                 objSuppliers.PostalCode = dr("PostalCode").ToString()
             Else
                 objSuppliers.PostalCode = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Country")) Then
                 objSuppliers.Country = dr("Country").ToString()
             Else
                 objSuppliers.Country = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Phone")) Then
                 objSuppliers.Phone = dr("Phone").ToString()
             Else
                 objSuppliers.Phone = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Fax")) Then
                 objSuppliers.Fax = dr("Fax").ToString()
             Else
                 objSuppliers.Fax = Nothing
             End If

             If Not DbNull.Value.Equals(dr("HomePage")) Then
                 objSuppliers.HomePage = dr("HomePage").ToString()
             Else
                 objSuppliers.HomePage = Nothing
             End If

             Return objSuppliers
         End Function
     End Class
End Namespace
