Imports System
Imports System.Web.UI.WebControls
Imports System.Configuration
Imports System.Text.RegularExpressions
Imports System.Web.UI
Imports System.IO

Namespace SearchSampleVB

    Public NotInheritable Class Functions
        Private Sub New()
        End Sub

        Public Shared Sub GridViewRowCreated(sender As Object, e As GridViewRowEventArgs, nonSortableColumnCount As Integer)
            If e IsNot Nothing Then
                If e.Row.RowType = DataControlRowType.Header Then
                    Dim gridView As GridView = DirectCast(sender, GridView)
                    Dim columnCount As Integer = gridView.Columns.Count - nonSortableColumnCount
                    Dim sortColumnIndex As Integer = GetSortColumnIndex(gridView)

                    If sortColumnIndex <> -1 AndAlso sortColumnIndex < columnCount Then
                        AddSortImage(gridView, sortColumnIndex, e.Row)
                    End If
                End If
            End If
        End Sub

        Private Shared Function GetSortColumnIndex(gridView As GridView) As Integer
            For Each field As DataControlField In gridView.Columns
                If Not String.IsNullOrEmpty(gridView.SortExpression) Then
                    If field.SortExpression = gridView.SortExpression Then
                        Return gridView.Columns.IndexOf(field)
                    End If
                End If
            Next

            Return -1
        End Function

        Private Shared Sub AddSortImage(gridView As GridView, columnIndex As Integer, headerRow As GridViewRow)
            Dim sortImage As New Image()

            If gridView.SortDirection = SortDirection.Ascending Then
                sortImage.ImageUrl = "~/" + ConfigurationManager.AppSettings("ArrowUp")
            Else
                sortImage.ImageUrl = "~/" + ConfigurationManager.AppSettings("ArrowDown")
            End If

            ' add the image to the appropriate header cell
            headerRow.Cells(columnIndex).Controls.Add(sortImage)
        End Sub

        Public Shared Sub GridViewRowDataBound(sender As Object, e As GridViewRowEventArgs, primaryKeyCount As Integer)
            If e IsNot Nothing Then
                If e.Row.RowType = DataControlRowType.DataRow Then
                    ' set hover highlight for the gridview
                    e.Row.Attributes.Add("onmouseover", "SetGridViewHoverOn(this);")
                    e.Row.Attributes.Add("onmouseout", "SetGridViewHoverOff(this);")
                End If
            End If
        End Sub

        Public Shared Sub ShowModalError(ex As Exception, page As Page, Optional errorDialogTitle As String = "")
            If ex IsNot Nothing Then
                ' show error
                Dim dialogTitle As String = [String].Empty

                If Not [String].IsNullOrEmpty(errorDialogTitle) Then
                    dialogTitle = ", '" + errorDialogTitle + "'"
                End If

                Dim errorMessage As String = Functions.RemoveSpecialChars(ex.Message)
                ScriptManager.RegisterStartupScript(page, page.[GetType](), "err_msg", "ShowError('" + errorMessage + "'" + dialogTitle + ");", True)
            End If
        End Sub

        Public Shared Sub ShowModalHtmlError(errorMessage As String, page As Page, errorDialogTitle As String)
            ' show error
            Dim dialogTitle As String = [String].Empty

            If Not [String].IsNullOrEmpty(errorDialogTitle) Then
                dialogTitle = ", '" + errorDialogTitle + "'"
            End If

            ScriptManager.RegisterStartupScript(page, page.[GetType](), "err_msg", "ShowHtmlError('" + errorMessage + "'" + dialogTitle + ");", True)
        End Sub

        Public Shared Function RoundToNearestTens(number As Integer) As Integer
            Return CInt(Math.Round(Convert.ToDecimal((number + 9) \ 10)) * 10)
        End Function

        Private Shared Function RemoveSpecialChars(text As String) As String
            Dim regex As New Regex("[^a-zA-Z0-9 -]")
            Return regex.Replace(text, "")
        End Function
    End Class

End Namespace
